@@ -5,11 +5,7 @@ from .version import version
 import warnings
 import textwrap
 import urllib
-
-try:
-    import simplejson as json
-except ImportError:
-    import json
+import json
 
 # TODO: use urlfetch for Google App Engine
 try:
@@ -29,6 +25,39 @@ except ImportError:
     _lib = 'urllib2'
     _lib_ver = urllib2.__version__
 
+
+def urlify(params, prefix=''):
+    def is_number(s):
+        try:
+            float(s)
+            return True
+        except ValueError:
+            return False
+
+    result = {}
+    items = params.items() if isinstance(params, dict) else enumerate(params)
+    for k, v in items:
+        key = '%s__%s' % (prefix, k) if prefix else k
+        if isinstance(v, dict) or isinstance(v, list):
+            result.update(urlify(v, key))
+        elif isinstance(v, bool):
+            result[key] = 'true' if v else 'false'
+        elif v is None:
+            result[key] = 'null'
+        elif isinstance(v, basestring):
+            if v in ('true', 'false', 'null') or is_number(v):
+                v = '"%s"' % v
+            if isinstance(v, unicode):
+                v = v.encode('utf8')
+            elif isinstance(v, str):
+                # Must be utf-8, raise exception if it isn't
+                v.decode('utf8')
+            result[key] = v
+        else:
+            result[key] = v
+    return result
+
+
 class API(object):
     def __init__(self, key=None, base_url=None):
         from .defaults import api_key, api_url
@@ -106,14 +135,11 @@ class API(object):
         headers = {
             'Authorization': 'Basic %s' % b64encode('%s:' % self.api_key),
             'User-Agent': 'Unipag Client for Python, v%s' % version,
+            'Content-Type': 'application/x-www-form-urlencoded',
             'X-Unipag-User-Agent-Info': json.dumps(client_info)
         }
 
-        # Do not pass params with None values
-        data = {}
-        for k, v in params.items():
-            if v is not None:
-                data[k] = v
+        data = urlify(params)
 
         # Send request to API and handle communication errors
         timeout = 60
